# The Keras model loading function does not play well with
# Pathlib at the moment, so we are using the old os module
# style

import os

PWD = os.path.dirname(os.path.abspath(__file__))
PACKAGE_ROOT = os.path.abspath(os.path.join(PWD, '..'))
DATASET_DIR = os.path.join(PACKAGE_ROOT, 'datasets')
TRAINED_MODEL_DIR = os.path.join(PACKAGE_ROOT, 'trained_models')
DATA_FOLDER = os.path.join(DATASET_DIR, 'text_data')

# MODEL PERSISTING
MODEL_NAME = 'language_model'
PIPELINE_NAME = 'lm_pipe'

# MODEL FITTING HYPERPARAMETERS
VOCAB_SIZE = 30000
BATCH_SIZE = 16
EPOCHS = int(os.environ.get('EPOCHS', 1))  # 1 for testing, 10 for final model


with open(os.path.join(PACKAGE_ROOT, 'VERSION')) as version_file:
    _version = version_file.read().strip()

MODEL_FILE_NAME = f'{MODEL_NAME}_{_version}.h5'
MODEL_PATH = os.path.join(TRAINED_MODEL_DIR, MODEL_FILE_NAME)

PIPELINE_FILE_NAME = f'{PIPELINE_NAME}_{_version}.pkl'
PIPELINE_PATH = os.path.join(TRAINED_MODEL_DIR, PIPELINE_FILE_NAME)



import numpy as np
import cv2
from keras.utils import np_utils
from sklearn.preprocessing import LabelEncoder
from sklearn.base import BaseEstimator, TransformerMixin


class CreateDataset(BaseEstimator, TransformerMixin):

    def __init__(self, image_size=50):
        self.image_size = image_size

    def fit(self, X, y=None):
        return self

    def transform(self, X):
        X = X.copy()
        # in the example, resize the batch of images
        return X



import joblib

from ows_language_model import pipeline as pipe
from ows_language_model.config import config
from ows_language_model.processing import data_management as dm
from ows_language_model.processing import preprocessors as pp


def run_training(save_result: bool = True):
    """Train a language model."""


    if save_result:
        joblib.dump(enc, config.ENCODER_PATH)
        dm.save_pipeline_keras(pipe.pipe)


if __name__ == '__main__':
    run_training(save_result=True)
